@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.2202';
+our $VERSION = '0.2203';
 
 use Carp;
 use Algorithm::Combinatorics qw( permutations );
@@ -37,6 +37,7 @@ sub expected_payoff
     my ($self) = @_;
 
     my $expected_payoff;
+
     # For each strategy of player 1...
     for my $i ( sort keys %{ $self->{1} } )
     {
@@ -64,6 +65,7 @@ sub s_expected_payoff
     my ($self) = @_;
 
     my $expected_payoff;
+
     # For each strategy of player 1...
     for my $i ( sort keys %{ $self->{1} } )
     {
@@ -115,12 +117,13 @@ sub counter_strategy
     my @pure = ( 1, (0) x ( @keys - 1 ) );
 
     my $i = permutations( \@pure );
-    while ( my $x = $i->next )
+
+    while ( my $strategies = $i->next )
     {
-        next if $seen{"@$x"}++;
+        next if $seen{"@$strategies"}++;
 
         my $g = Game::Theory::TwoPersonMatrix->new(
-            $player   => { zip @keys, @$x },
+            $player   => { zip @keys, @$strategies },
             $opponent => $self->{$opponent},
             payoff    => $self->{payoff} || $self->{"payoff$player"},
         );
@@ -312,13 +315,17 @@ sub mm_tally
         # Find minimum of column maximums for the opponent
         my @m = ();
         my %s = ();
+
         my $transposed = transpose( $self->{payoff2} );
+
         for my $row ( 0 .. @$transposed - 1 )
         {
             $s{$row} = min @{ $transposed->[$row] };
             push @m, $s{$row};
         }
+
         $mm_tally->{2}{value} = max @m;
+
         for my $row ( sort keys %s )
         {
             push @{ $mm_tally->{2}{strategy} }, ( $s{$row} == $mm_tally->{2}{value} ? 1 : 0 );
@@ -332,13 +339,17 @@ sub mm_tally
         # Find minimum of column maximums
         my @m = ();
         my %s = ();
+
         my $transposed = transpose( $self->{payoff} );
+
         for my $row ( 0 .. @$transposed - 1 )
         {
             $s{$row} = max @{ $transposed->[$row] };
             push @m, $s{$row};
         }
+
         $mm_tally->{2}{value} = min @m;
+
         for my $row ( sort keys %s )
         {
             push @{ $mm_tally->{2}{strategy} }, ( $s{$row} == $mm_tally->{2}{value} ? 1 : 0 );
@@ -396,9 +407,11 @@ sub pareto_optimal
                 for my $c ( 0 .. $csize )
                 {
                     next if ( $r == $row && $c == $col ) || $seen{"$r,$c"}++;
+
                     my $p = $self->{payoff1}[$row][$col];
                     my $q = $self->{payoff2}[$row][$col];
 #warn "\trc:$r,$c = ($self->{payoff1}[$r][$c],$self->{payoff2}[$r][$c])\n";
+
                     if ( $p >= $self->{payoff1}[$r][$c] && $q >= $self->{payoff2}[$r][$c] )
                     {
 #warn "\t\t$row,$col > $r,$c at ($p,$q)\n";
@@ -438,8 +451,10 @@ sub nash
                 push @col, $self->{payoff1}[$r][$col];
             }
             my $cmax = max @col;
+
             my $p = $self->{payoff1}[$row][$col];
             my $q = $self->{payoff2}[$row][$col];
+
             if ( $p == $cmax && $q == $rmax )
             {
 #warn "\t$p == $cmax && $q == $rmax\n";
@@ -497,7 +512,7 @@ Game::Theory::TwoPersonMatrix - Analyze a 2 person matrix game
 
 =head1 VERSION
 
-version 0.2202
+version 0.2203
 
 =head1 SYNOPSIS
 
@@ -510,8 +525,8 @@ version 0.2202
                 [ 3,-2, 2],
                 [ 2,-3, 1] ]
  );
- $g->row_reduce();
  $g->col_reduce();
+ $g->row_reduce();
  my $player = 1;
  my $x = $g->saddlepoint();
  $x = $g->oddments();
@@ -541,7 +556,7 @@ version 0.2202
 
 =head1 DESCRIPTION
 
-A C<Game::Theory::TwoPersonMatrix> analyzes a two person matrix game of player
+C<Game::Theory::TwoPersonMatrix> analyzes a two person matrix game of player
 names, strategies and utilities ("payoffs").
 
 Players 1 and 2 are the "row" and "column" players, respectively.  This is due
@@ -578,8 +593,8 @@ And in this implementation that would be:
     payoff2 => [ [ -1,  0 ], [ -3, -2 ] ],  # Red:  [ R2, T2 ], [ S2, P2 ]
  );
 
-Where the two player strategies are to either Cooperate (1) or Defect (2).  This
-is given by a hash for each of the two players, where the values are Boolean:
+The two player strategies are to either cooperate (1) or defect (2).  This is
+given by a hash for each of the two players, where the values are Boolean:
 
  %strategies = (
     1 => { 1 => $cooporate1, 2 => $defect1 }, # Blue
@@ -615,11 +630,15 @@ Payoffs are given by array references of lists of outcomes.  For zero-sum games
 this is a single payoff list.  For non-zero-sum games this is given as two lists
 - one for each player.
 
+The number of row and column payoff values must equal the number of the player
+and opponent strategies, respectively.
+
 =head2 expected_payoff
 
  $x = $g->expected_payoff();
 
-Return the expected payoff value of a game.
+Return the expected payoff of a game.  This is the sum of the strategic
+probabilities of each payoff.
 
 =head2 s_expected_payoff
 
@@ -629,6 +648,7 @@ Return the expected payoff value of a game.
     payoff => [ ['a','b'], ['c','d'] ]
  );
  $x = $g->s_expected_payoff();
+ # (1 - p) * 1 * a + (1 - p) * 0 * b + p * 1 * c + p * 0 * d
 
 Return the symbolic expected payoff expression for a non-numeric game.
 
@@ -639,8 +659,8 @@ F<eg/> examples.
 
  $x = $g->counter_strategy($player);
 
-Return the expected payoff, for a given player, of either a zero-sum or
-non-zero-sum game, given pure opponent strategies.
+Return the expected payoff for a given player, of either a zero-sum or
+non-zero-sum game, given pure strategies.
 
 =head2 saddlepoint
 
@@ -687,7 +707,7 @@ Return the Pareto optimal outcomes for a non-zero-sum game.
 
  $x = $g->nash();
 
-Identify the Nash equilibria in a non-zero-sum game.
+Identify the Nash equilibria.
 
 Given payoff pair C<(a,b)>, B<a> is maximum for its column and B<b> is maximum
 for its row.
